==> fluent-validation-support-1.1-sources.jar: fluent/validation/Quantifier.java <==
/*
 * Copyright © 2018 Ondrej Fischer. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *    following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * 3. The name of the author may not be used to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY [LICENSOR] "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package fluent.validation;

import fluent.validation.detail.CheckVisitor;

final class Quantifier<D> extends Check<Iterable<D>> {

    private final Check<? super D> check;
    private final boolean end;

    Quantifier(Check<? super D> check, boolean end) {
        this.check = check;
        this.end = end;
    }


    @Override
    public boolean test(Iterable<D> data, CheckVisitor checkVisitor) {
        CheckVisitor node = checkVisitor.node(this);
        for(D item : data) {
            if(end == check.test(item, node)) {
                return trace(node, "", end);
            }
        }
        return trace(node, "", !end);
    }

    @Override
    public String name() {
        return end ? "exists" : "every";
    }

    @Override
    public String toString() {
        return end ? "exists element matching " + check : "every element matches " + check;
    }

}

==> fluent-validation-support-2.6-sources.jar: fluent/validation/Quantifier.java <==
/*
 * Copyright © 2018 Ondrej Fischer. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *    following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * 3. The name of the author may not be used to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY [LICENSOR] "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package fluent.validation;

import fluent.validation.result.Aggregator;
import fluent.validation.result.Result;
import fluent.validation.result.ResultFactory;

final class Quantifier<D> extends Check<Iterable<D>> {

    private final String elementName;
    private final Type type;
    private final Check<? super D> check;

    Quantifier(String elementName, Type type, Check<? super D> check) {
        this.elementName = elementName;
        this.type = type;
        this.check = check;
    }

    @Override
    public Result evaluate(Iterable<D> data, ResultFactory factory) {
        Aggregator itemResults = factory.aggregator(this);
        boolean end = type == Type.exists;
        for(D item : data) {
            if(itemResults.add(check.evaluate(item, factory)).passed() == end) {
                return end ? itemResults.build(elementName + " " + check + " found", true) : itemResults.build(item + " doesn't match " + check, false);
            }
        }
        return end ? itemResults.build("No " + elementName + " " + check + " found", false) : itemResults.build("All " + elementName + "s matched " + check, true);
    }

    @Override
    public String toString() {
        return type + " " + elementName + " " + check;
    }

    enum Type {exists, every}

}
